# Försäkringskassans Leverera kundavisering (LEKA) - Testmiljö

E-tjänsten _Leverera kundavisering_ (LEKA) notifierar anslutna organisationer om förändringar av Försäkringskassans och Pensionsmyndighetens kunders ärenden och uppgifter, vilka sedan kan hämtas via e-tjänsten _Leverera förmånsinformation_ (LEFI). Det här arkivet samlar den information som behövs för att fysiskt ansluta till och nyttja Försäkringskassans testmiljö för LEKA, vilken inkluderar API-specifikationer, URL:er och beskrivningar.

Mer information om LEKA hittar du på https://www.forsakringskassan.se/myndigheter-och-samarbetspartner/e-tjanster-for-myndigheter-och-samarbetspartner/leka.

## Innehållsförteckning
1. Tjänstebeskrivning
    - 1.1 Prenumeration
    - 1.2 Avisering
2. Miljöbeskrivning
    - 2.1 Anslutning
    - 2.2 Begränsningar
    - 2.3 Specialfall

## 1. Tjänstebeskrivning

LEKA låter en ansluten organisation, såsom ett försäkringsbolag eller en kommun, att hantera _prenumerationer_ på _aviseringar_ om uppdaterade ärenden eller tillkomna uppgifter om Försäkringskassans kunder. Aviseringarna i sig innehåller inte den nya informationen. Istället förutsätts mottagaren av respektive avisering själv hämta informationen via e-tjänsten [LEFI:s][LEFI] gränssnitt.

[LEFI]: https://www.forsakringskassan.se/myndigheter-och-samarbetspartner/e-tjanster-for-myndigheter-och-samarbetspartner/lefi-online

Prenumerationer och aviseringar hanteras respektive hämtas via de två HTTP-baserade gränssnitt som beskrivs i de följande underavsnitten. De båda tjänsternas _OpenAPI-specifikationer_, vilka är programmatiska beskrivningar av gränssnittens operationer och datatyper, finns att hitta i mappen `openapi/`.

### 1.1 Prenumeration

Gränssnittet låter en ansluten organisation skapa, hämta och ta bort _prenumerationer_ på aviseringar. Varje sådan prenumeration rör en kund hos Försäkringskassan, identifierad med personnummer, och innehåller en lista av de kategorier av socialförsäkringsinformation, eller _förmåner_, prenumeranten önskar bli aviserad om.

Det finns inte möjlighet att prenumerara på alla förmåner det går att hämta information om via [LEFI][LEFI]. Detta är en begränsning i den aktuella versionen av LEKA, och inte något som är unikt för testmiljön. Dessutom sker görs också begränsningar i förmedlade förmåner baserat på det _regelverk för utlämnande_ som beslutats av Försäkringskassan för respektive organisation. Dock appliceras dessa regelverk inte i testmiljön.

### 1.2 Avisering

Gränssnittet låter en ansluten organisation __hämta__ _aviseringar_ associerade med skapade och aktiva prenumerationer. Notera att LEKA alltså _inte_ skickar ut aviseringarna till organisationernas servrar, utan samlar dem i virtuella brelådor respektive organisation måste tömma regelbundet på egen hand. Aviseringar bör inte hämtas oftare än var 10:e sekund för integrationstester som körs under kortare perioder. Pågår ett test i flera timmar eller längre bör inte aviseringar hämtas oftare än en gång i timmen.

Kunder hos Försäkringskassan kan av olika anledningar avregistreras eller få sina personnummer utbytta. Om detta påträffar samtidigt som det finns en prenumeration på den kunden meddelas prenumeranten igenom en speciell avisering, varefter prenumerationen avaktiveras permanent. I testmiljön simuleras detta igenom att aktivera två specialfall beskrivna i sektion 2.3.

Aviseringar kan hämtas _flera gånger_. Dock finns begränsningen att en avisering som inte hämtats kommer att gallras _en vecka efter att den skapats_ i LEKA. Likaså kommer en avisering som hämtats gallras _en vecka efter att den hämtats den första gången_ från LEKA.

## 2. Miljöbeskrivning

LEKA:s testmiljö existerar enbart för att anslutna organisationer ska kunna utvärdera om deras integrationer fungerar tillsammans med LEKA:s gränssnitt. För att miljön ska kunna tjäna detta syfte har vissa begränsningar och specialanpassningar gjorts, vilka särskiljer den från produktionsmiljön.

I följande underavsnitt beskrivs hur en organisation ansluter till testmiljön, samt vilka begränsningar och specialanpassningar som gjorts.

### 2.1 Anslutning

Nyttjande av LEKA:s testmiljö kräver att en HTTPS-klient används som är konfigurerad att använda ett klient-certifikat som godkänns av Försäkringskassan. Instruktioner om hur ett godkänt certifikat erhålls, samt vilka certifikat som måste betraktas som betrodda, finns på [websidan för LEFI Online][LEFI].

#### 2.1.1 Gränssnittens URL:er

När ett godkänt certifikat är på plats (och HTTPS-klienten i fråga är konfigurerad att använda det med mTLS) ska följande bas-URL:er användas för att skicka meddelanden till de båda gränssnitten.

| Gränssnitt    | Bas-URL                                                                                      |
|:--------------|:---------------------------------------------------------------------------------------------|
| Prenumeration | https://shsext.forsakringskassan.se:8200/rest/FK.EXI.LevereraKundAvisering.Prenumeration.V9/ |
| Avisering     | https://shsext.forsakringskassan.se:8200/rest/FK.EXI.LevereraKundAvisering.Avisering.V9/     |

En bas-URL är alltså en URL som saknar sökvägen från en specifik API-operation. För att, exempelvis, skicka ett meddelande till aviseringsgränssnittets operation `hamtaAviseringar`, vilken har sökvägen `/leka-extern-avisering/v9/aktorer/{aktorsId}/aviseringar`, måste följande sökväg användas:

```
https://shsext.forsakringskassan.se:8200/rest/FK.EXI.LevereraKundAvisering.Avisering.V9/leka-extern-avisering/v9/aktorer/{aktorsId}/aviseringar
```

URL-schemat och -auktoriteten som används av samtliga utav testmiljöns operationer är alltså `https://shsext.forsakringskassan.se:8200/rest`. Denna typ av URL referas också till som _inlämningsadress_ i övrig dokumentation för LEFI Online.

#### 2.1.2 Header "Content-Type"

Kontrollera att headern ’Content-Type: application/json’ är satt i anropet till tjänsten, annars går det fel redan i integrationen.

### 2.2 Begränsningar

#### 2.2.1 Begränsad säkerhet

Inga garantier ges om att en organisation inte kan hantera respektive hämta andra organisationers prenumerationer och aviseringar. Av respekt för andra organisationer bör dock varje organisation låta bli att söka upp och modifiera deras prenumerationer eller aviseringar.

#### 2.2.2 Begränsad persistens

Data som sparas av anslutna organisationer, såsom prenumerationer, kan försvinna från testmiljön när som helst. Testmiljön kan återställas till sitt ursprungliga skick när som helst, även om det i praktiken inte lär ske oftare än en gång om dygnet.

#### 2.2.3 Begränsad tillgänglighet

Testmiljön bör finnas tillgänglig mellan klockan 08:00 till 17:00 under vanliga vardagar. Den kan vara otillgänglig i kortare perioder under denna tid på grund utav uppgraderingar, omstarter och oförutsedda händelser. Testmiljön _kan_ finnas tillgänglig övrig tid.

#### 2.2.4 Ingen behörighetskontroll

Produktionsmiljön tillämpar olika regelverk för utlämnanande för respektive typ av ansluten organisation. Regelverken avgör vilka organisationer som har rätt att ta emot aviseringar på vilka förmåner. _Dock sker ingen tillämpning av regelverk i testmiljön_. Det betyder att samtliga organisationer har rätt till alla förmåner, även om de inte har det i produktionsmiljön.

#### 2.2.5 Maximalt antal prenumerationer och informationstyper

I testmiljön tillåts maximalt 16 prenumerationer per aktör, där varje aktör maximalt kommer att tillåtas ha 16 aviseringar liggande. Läggs fler prenumerationer till för aktören, kommer tidigare att rensas bort. För aviseringar gäller att tidigare aviseringar rensas bort när nya skapas. Det finns heller ingen kontroll av att aviseringar är unika, dvs det kan finnas flera aviseringar för samma informationstyp att hämta.

### 2.3 Specialfall

#### 2.3.1 Skapa prenumeration för kund med slumpmässig avisering

För att göra det möjligt för skapade prenumerationer att överhuvudtaget erhålla aviseringar genereras aviseringar slumpmässigt varje gång en prenumeration skapas, med undantag för de personnummer som finns i de följande specialfallen. Framslumpade aviseringar kommer alltid att ha en av de förmåner som angetts i anropet som skapade prenumerationen.

Notera att aviseringar bara kan hämtas en gång i testmiljön. När en avisering väl har hämtats tas den bort.

#### 2.3.2 Skapa prenumeration för kund med avisering om personnummerbyte

_Stöd för detta specialfall kommer i nästa uppdatering av testmiljön._

Om en prenumeration skapas för kunden med personnummer `xxxxxxxxxxxx` ` skapas en speciell avisering för den prenumerationen om ett _personnummerbyte_. Ingen slumpmässig avisering skapas, såsom beskrivet i sektion 2.3.1.

#### 2.3.3 Skapa prenumeration för kund som sedan avregistreras

_Stöd för detta specialfall kommer i nästa uppdatering av testmiljön._

Om en prenumeration skapas för kunden med personnummer `yyyyyyyyyyyy` skapas en speciell avisering för den prenumerationen om en _avregistrering_. Ingen slumpmässig avisering skapas, såsom beskrivet i sektion 2.3.1.

#### 2.3.4 Anrop för kund som inte finns i kundregistret

Om en prenumeration skapas eller en avisering ska hämtas för kunder med följande personnummer misslyckas försöket med angivelsen att kunden inte finns registrerad hos någon eller båda av bastjänsterna (Försäkringskassan eller Pensionsmyndigheten).

| Personnummer | Felande bas-tjänst |
|:--------------|:----------------------------------------------------------------------------------------------|
| 195101151818 | Båda |
| 195101151818 | Båda |
| 198001222390 | Båda |
| 198001032385 | FK   |
| 198001032393 | PM   |

#### 2.3.5 Anrop går till timeout eller får lång svarstid

Om en prenumeration skapas eller en avisering ska hämtas för kunder med följande personnummer misslyckas försöket på grund av timeout för tjänsten eller en eller någon av eller båda bastjänsterna (Försäkringskassan eller Pensionsmyndigheten). Det sista personnumret leder till en svarstid på 35 sekunder för tjänsten.

| Personnummer | Felande bas-tjänst |
|:--------------|:----------------------------------------------------------------------------------------------|
| 192601108356 | Båda |
| 201001222387 | Båda |
| 198001022386 | FK   |
| 198001022394 | PM   |
| 201001062395 | Båda (35 sekunders svarstid) |


#### 2.3.6 Anrop orsakar internal server error

Om en prenumeration skapas eller en avisering ska hämtas för kunder med följande personnummer misslyckas försöket på grund av internal server error för tjänsten eller någon av eller båda bastjänsterna (Försäkringskassan eller Pensionsmyndigheten). 

| Personnummer | Felande bas-tjänst |
|:--------------|:----------------------------------------------------------------------------------------------|
| 201001062387 |      |
| 190002249803 | Båda |
| 201402172389 | Båda |
| 198001042384 | FK   |
| 198001042392 | PM   |

#### 2.3.7 Anrop när auktorisering saknas

Om en prenumeration skapas eller en avisering ska hämtas för kunder med följande personnummer misslyckas försöket på grund av auktoriering saknas för tjänsten eller någon av eller båda bastjänsterna (Försäkringskassan eller Pensionsmyndigheten).

| Personnummer | Felande bas-tjänst |
|:--------------|:----------------------------------------------------------------------------------------------|
| 201301222392 |  |
| 199002042381 |  |
| 201502162397 |  |
| 201604112381 |  |
| 201702142397 |  |
| 202101162390 |  |
| 202202192387 |  | 
| 202302232380 |  |
| 201902212388 |  |
| 202002232383 |  |
| 200001252394 |  |
| 200112212394 |  |
| 200311142384 |  |
| 200509162392 |  |
| 198001062390 | FK |
| 198001062382 | PM |
